@@ -5,19 +5,13 @@ agent - Decorator-based Computer Use Agent with liteLLM integration
 import logging
 import sys
 
-from .decorators import register_agent
-from .agent import ComputerAgent
-from .types import Messages, AgentResponse
-
 # Import loops to register them
 from . import loops
+from .agent import ComputerAgent
+from .decorators import register_agent
+from .types import AgentResponse, Messages
 
-__all__ = [
-    "register_agent",
-    "ComputerAgent",
-    "Messages",
-    "AgentResponse"
-]
+__all__ = ["register_agent", "ComputerAgent", "Messages", "AgentResponse"]
 
 __version__ = "0.4.0"
 
