@@ -8,6 +8,7 @@ with a Gradio UI for human interaction.
 
 import gradio as gr
 from fastapi import FastAPI
+
 from .server import app as fastapi_app
 from .ui import create_ui
 
@@ -18,6 +19,7 @@ gradio_demo = create_ui()
 CUSTOM_PATH = "/gradio"
 app = gr.mount_gradio_app(fastapi_app, gradio_demo, path=CUSTOM_PATH)
 
+
 # Add a redirect from root to Gradio UI
 @fastapi_app.get("/")
 async def redirect_to_ui():
@@ -25,14 +27,16 @@ async def redirect_to_ui():
     return {
         "message": "Human Completion Server is running",
         "ui_url": "/gradio",
-        "api_docs": "/docs"
+        "api_docs": "/docs",
     }
 
+
 if __name__ == "__main__":
     import uvicorn
+
     print("🚀 Starting Human-in-the-Loop Completion Server...")
     print("📊 API Server: http://localhost:8002")
     print("🎨 Gradio UI: http://localhost:8002/gradio")
     print("📚 API Docs: http://localhost:8002/docs")
-    
+
     uvicorn.run(app, host="0.0.0.0", port=8002)
