@@ -9,26 +9,26 @@ Key differences from the OpenAI OperatorAgent variant:
 - Planning is executed via `ComputerAgent.run(messages)`.
 - The first yielded result per step is returned as the agent response.
 """
+
 from __future__ import annotations
 
+import base64
 import io
+import uuid
+from pathlib import Path
 from typing import Any, ClassVar, Optional
 
+import hud
+import mcp.types as types
 from agent.agent import ComputerAgent as BaseComputerAgent
 from agent.callbacks import PromptInstructionsCallback
 from agent.callbacks.trajectory_saver import TrajectorySaverCallback
+from agent.computers import is_agent_computer
+from agent.responses import make_failed_tool_call_items
 from hud.agents import MCPAgent
 from hud.tools.computer.settings import computer_settings
 from hud.types import AgentResponse, MCPToolCall, MCPToolResult, Trace
-
-from agent.responses import make_failed_tool_call_items
-from agent.computers import is_agent_computer
 from PIL import Image
-import mcp.types as types
-import hud
-import uuid
-import base64
-from pathlib import Path
 
 
 class MCPComputerAgent(MCPAgent):
@@ -114,8 +114,10 @@ class MCPComputerAgent(MCPAgent):
         self.last_screenshot_b64 = None
 
         buffer = io.BytesIO()
-        Image.new('RGB', (self.metadata["display_width"], self.metadata["display_height"])).save(buffer, format='PNG')
-        self.last_screenshot_b64 = base64.b64encode(buffer.getvalue()).decode('utf-8')
+        Image.new("RGB", (self.metadata["display_width"], self.metadata["display_height"])).save(
+            buffer, format="PNG"
+        )
+        self.last_screenshot_b64 = base64.b64encode(buffer.getvalue()).decode("utf-8")
 
         # Ensure a computer shim is present so width/height/environment are known
         computer_shim = {
@@ -128,12 +130,8 @@ class MCPComputerAgent(MCPAgent):
         }
         agent_tools: list[Any] = [computer_shim]
         if tools:
-            agent_tools.extend([
-                tool 
-                for tool in tools 
-                if not is_agent_computer(tool)
-            ])
-        
+            agent_tools.extend([tool for tool in tools if not is_agent_computer(tool)])
+
         agent_kwargs = {
             "model": self.model,
             "trajectory_dir": trajectory_dir,
@@ -150,9 +148,7 @@ class MCPComputerAgent(MCPAgent):
             "telemetry_enabled": telemetry_enabled,
         }
 
-        self.computer_agent = BaseComputerAgent(
-            **agent_kwargs
-        )
+        self.computer_agent = BaseComputerAgent(**agent_kwargs)
 
     async def get_system_messages(self) -> list[Any]:
         """Create initial messages.
@@ -161,9 +157,7 @@ class MCPComputerAgent(MCPAgent):
         """
         return []
 
-    async def format_blocks(
-        self, blocks: list[types.ContentBlock]
-    ) -> list[dict[str, Any]]:
+    async def format_blocks(self, blocks: list[types.ContentBlock]) -> list[dict[str, Any]]:
         """
         Format blocks for OpenAI input format.
 
@@ -200,42 +194,49 @@ class MCPComputerAgent(MCPAgent):
 
         # Call the ComputerAgent LLM API
         async for result in self.computer_agent.run(messages):  # type: ignore[arg-type]
-            items = result['output']
+            items = result["output"]
             if not items or tool_calls:
                 break
 
             for item in items:
-                if item['type'] in ['reasoning', 'message', 'computer_call', 'function_call', 'function_call_output']:
+                if item["type"] in [
+                    "reasoning",
+                    "message",
+                    "computer_call",
+                    "function_call",
+                    "function_call_output",
+                ]:
                     agent_result.append(item)
-                
+
                 # Add messages to output text
-                if item['type'] == 'reasoning':
+                if item["type"] == "reasoning":
                     output_text.extend(
-                        f"Reasoning: {summary['text']}"
-                        for summary in item['summary']
+                        f"Reasoning: {summary['text']}" for summary in item["summary"]
                     )
-                elif item['type'] == 'message':
-                    if isinstance(item['content'], list):
+                elif item["type"] == "message":
+                    if isinstance(item["content"], list):
                         output_text.extend(
-                            item['text'] 
-                            for item in item['content']
-                            if item['type'] == 'output_text'
+                            item["text"]
+                            for item in item["content"]
+                            if item["type"] == "output_text"
                         )
-                    elif isinstance(item['content'], str):
-                        output_text.append(item['content'])
-                
+                    elif isinstance(item["content"], str):
+                        output_text.append(item["content"])
+
                 # If we get a tool call, we're not done
-                if item['type'] == 'computer_call':
+                if item["type"] == "computer_call":
                     id = item["call_id"]
-                    tool_calls.append(MCPToolCall(
-                        name="openai_computer",
-                        arguments=item["action"],
-                        id=id,
-                    ))
+                    tool_calls.append(
+                        MCPToolCall(
+                            name="openai_computer",
+                            arguments=item["action"],
+                            id=id,
+                        )
+                    )
                     is_done = False
                     self.tool_call_inputs[id] = agent_result
                     break
-            
+
             # if we have tool calls, we should exit the loop
             if tool_calls:
                 break
@@ -247,7 +248,7 @@ class MCPComputerAgent(MCPAgent):
             tool_calls=tool_calls,
             done=is_done,
         )
-    
+
     def _log_image(self, image_b64: str):
         callbacks = self.computer_agent.callbacks
         for callback in callbacks:
@@ -257,9 +258,7 @@ class MCPComputerAgent(MCPAgent):
                 callback._save_artifact("screenshot_after", image_bytes)
 
     async def format_tool_results(
-        self,
-        tool_calls: list[MCPToolCall],
-        tool_results: list[MCPToolResult]
+        self, tool_calls: list[MCPToolCall], tool_results: list[MCPToolResult]
     ) -> list[dict[str, Any]]:
         """Extract latest screenshot from tool results in dict form.
 
@@ -274,45 +273,60 @@ class MCPComputerAgent(MCPAgent):
                 previous_output = self.previous_output.copy() or []
 
                 # First we need to remove any pending computer_calls from the end of previous_output
-                while previous_output and previous_output[-1]['type'] == 'computer_call':
+                while previous_output and previous_output[-1]["type"] == "computer_call":
                     previous_output.pop()
                 messages.extend(previous_output)
 
                 # If the call is a 'response', don't add the result
-                if call.name == 'response':
+                if call.name == "response":
                     continue
                 # Otherwise, if we have a result, we should add it to the messages
                 content = [
-                    { "type": "input_text", "text": content.text } if isinstance(content, types.TextContent)
-                    else { "type": "input_image", "image_url": f"data:image/png;base64,{content.data}" } if isinstance(content, types.ImageContent)
-                    else { "type": "input_text", "text": "" }
+                    (
+                        {"type": "input_text", "text": content.text}
+                        if isinstance(content, types.TextContent)
+                        else (
+                            {
+                                "type": "input_image",
+                                "image_url": f"data:image/png;base64,{content.data}",
+                            }
+                            if isinstance(content, types.ImageContent)
+                            else {"type": "input_text", "text": ""}
+                        )
+                    )
                     for content in result.content
                 ]
-                messages.append({
-                    "role": "user",
-                    "content": content,
-                })
+                messages.append(
+                    {
+                        "role": "user",
+                        "content": content,
+                    }
+                )
 
                 continue
-                
+
             # Add the assistant's computer call
             messages.extend(self.tool_call_inputs[call.id])
-            
+
             if result.isError:
-                error_text = "".join([
-                    content.text
-                    for content in result.content
-                    if isinstance(content, types.TextContent)
-                ])
+                error_text = "".join(
+                    [
+                        content.text
+                        for content in result.content
+                        if isinstance(content, types.TextContent)
+                    ]
+                )
 
                 # Replace computer call with failed tool call
                 messages.pop()
-                messages.extend(make_failed_tool_call_items(
-                    tool_name=call.name,
-                    tool_kwargs=call.arguments or {},
-                    error_message=error_text,
-                    call_id=call.id,
-                ))
+                messages.extend(
+                    make_failed_tool_call_items(
+                        tool_name=call.name,
+                        tool_kwargs=call.arguments or {},
+                        error_message=error_text,
+                        call_id=call.id,
+                    )
+                )
             else:
                 # Get the latest screenshot
                 screenshots = [
@@ -325,23 +339,27 @@ class MCPComputerAgent(MCPAgent):
                 if screenshots:
                     self._log_image(screenshots[0])
                     self.last_screenshot_b64 = screenshots[0]
-                    messages.append({
-                        "type": "computer_call_output",
-                        "call_id": call.id,
-                        "output": {
-                            "type": "input_image",
-                            "image_url": f"data:image/png;base64,{screenshots[0]}"
-                        },
-                    })
+                    messages.append(
+                        {
+                            "type": "computer_call_output",
+                            "call_id": call.id,
+                            "output": {
+                                "type": "input_image",
+                                "image_url": f"data:image/png;base64,{screenshots[0]}",
+                            },
+                        }
+                    )
                 else:
                     # Otherwise, replace computer call with failed tool call
                     messages.pop()
-                    messages.extend(make_failed_tool_call_items(
-                        tool_name=call.name,
-                        tool_kwargs=call.arguments or {},
-                        error_message="No screenshots returned.",
-                        call_id=call.id,
-                    ))
+                    messages.extend(
+                        make_failed_tool_call_items(
+                            tool_name=call.name,
+                            tool_kwargs=call.arguments or {},
+                            error_message="No screenshots returned.",
+                            call_id=call.id,
+                        )
+                    )
 
         return messages
 
